using System;
using System.IO;
using System.Globalization;

namespace PageBoxGrid
{
	/// <summary>
	/// <p>Write log entries.</p>
	/// <p>Copyright (c) 2002 Alexis Grandemange<br/>
	/// Mail: alexis.grandemange@pagebox.net</p>
	/// <pre>This program is free software; you can redistribute it and/or
	/// modify it under the terms of the GNU Lesser General Public
	/// License as published by the Free Software Foundation; version
	/// 2.1 of the License.
	/// This library is distributed in the hope that it will be useful,
	/// but WITHOUT ANY WARRANTY; without even the implied warranty of
	/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	/// GNU Lesser General Public License for more details.
	/// A copy of the GNU Lesser General Public License lesser.txt should be
	/// included in the distribution.</pre>
	/// </summary>
	public class Log
	{
		/// <summary>
		/// Name of the Log file.
		/// </summary>
		public string filename;
		/// <summary>
		/// StreamWriter opened on Log file.
		/// </summary>
		private StreamWriter sw = null;

		/// <summary>
		/// Constructor. Sets the name of the Log file. 
		/// </summary>
		/// <param name="fn"></param>
		public Log(string fn) 
		{
			filename = fn;
		}
		/// <summary>
		/// Write a log line.
		/// </summary>
		/// <param name="cmd">command</param>
		public void write(string cmd)
		{
			lock(this) 
			{
				DateTime dt = DateTime.Now;
				if (sw == null)
					sw = File.AppendText(filename);
				sw.WriteLine(dt.ToString("u", DateTimeFormatInfo.InvariantInfo) + ": " + cmd);
				sw.Flush();
			}
		}
	}
}
